@@ -151,6 +151,11 @@ ClassMeta *ObjectPad_mop_get_class_for_stash(pTHX_ HV *stash)
   return NUM2PTR(ClassMeta *, SvUV(SvRV(GvSV(*gvp))));
 }
 
+SV *ObjectPad_mop_class_get_name(pTHX_ ClassMeta *class)
+{
+  return class->name;
+}
+
 #define make_instance_fields(classmeta, backingav, roleoffset)  S_make_instance_fields(aTHX_ classmeta, backingav, roleoffset)
 static void S_make_instance_fields(pTHX_ const ClassMeta *classmeta, AV *backingav, FIELDOFFSET roleoffset)
 {
@@ -640,6 +645,23 @@ MethodMeta *ObjectPad_mop_class_add_method(pTHX_ ClassMeta *meta, SV *methodname
   return methodmeta;
 }
 
+MethodMeta *ObjectPad_mop_class_add_method_cv(pTHX_ ClassMeta *meta, SV *methodname, CV *cv)
+{
+  MethodMeta *methodmeta = mop_class_add_method(meta, methodname);
+
+  I32 klen = SvCUR(methodname);
+  if(SvUTF8(methodname))
+    klen = -klen;
+  GV **gvp = (GV **)hv_fetch(meta->stash, SvPVX(methodname), klen, GV_ADD);
+  gv_init_sv(*gvp, meta->stash, methodname, 0);
+  GvMULTI_on(*gvp);
+
+  GvCV_set(*gvp, cv);
+  CvGV_set(cv, *gvp);
+
+  return methodmeta;
+}
+
 FieldMeta *ObjectPad_mop_class_add_field(pTHX_ ClassMeta *meta, SV *fieldname)
 {
   AV *fields = meta->direct_fields;
