@@ -575,10 +575,10 @@ static void S_generate_field_accessor_method(pTHX_ FieldMeta *fieldmeta, SV *mna
   SvREFCNT_inc(PL_compcv);
   ops = block_end(save_ix, ops);
 
-  CV *cv = newATTRSUB(floor_ix, newSVOP(OP_CONST, 0, mname_fq), NULL, NULL, ops);
+  CV *cv = newATTRSUB(floor_ix, NULL, NULL, NULL, ops);
   CvMETHOD_on(cv);
 
-  mop_class_add_method(classmeta, mname);
+  mop_class_add_method_cv(classmeta, mname, cv);
 
   LEAVE;
 }
